@@ -51,10 +51,14 @@ Styles::Styles(CreateFlag flag)
     //!Fix me! Where should we put these register code?
     if (QMetaType::type("XlsxColor") == QMetaType::UnknownType) {
         qRegisterMetaType<XlsxColor>("XlsxColor");
+        //TODO: 需要测试
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         qRegisterMetaTypeStreamOperators<XlsxColor>("XlsxColor");
 #if QT_VERSION >= 0x050200
         QMetaType::registerDebugStreamOperator<XlsxColor>();
 #endif
+#endif
+
     }
 
     if (flag == F_NewFromScratch) {
