@@ -40,6 +40,7 @@ DeviceGpu::DeviceGpu()
 
 void DeviceGpu::initFilterKey()
 {
+    qCDebug(appLog) << "DeviceGpu::initFilterKey called.";
     // 添加可显示属性
     addFilterKey(QObject::tr("Device"));
     addFilterKey(QObject::tr("SubVendor"));
@@ -56,6 +57,7 @@ void DeviceGpu::initFilterKey()
     addFilterKey(QObject::tr("EGL client APIs"));
     addFilterKey(QObject::tr("GL version"));
     addFilterKey(QObject::tr("GLSL version"));
+    qCDebug(appLog) << "Filter keys initialized.";
 }
 
 void DeviceGpu::loadBaseDeviceInfo()
@@ -68,6 +70,7 @@ void DeviceGpu::loadBaseDeviceInfo()
     addBaseDeviceInfo(tr("Model"), m_Model);
     addBaseDeviceInfo(tr("Version"), m_Version);
     addBaseDeviceInfo(tr("Graphics Memory"), m_GraphicsMemory);
+    qCDebug(appLog) << "Base device info loaded.";
 }
 
 void DeviceGpu::setLshwInfo(const QMap<QString, QString> &mapInfo)
@@ -82,6 +85,7 @@ void DeviceGpu::setLshwInfo(const QMap<QString, QString> &mapInfo)
 
     // 设置属性
     if ((m_Name.isEmpty() || m_Name.startsWith("pci")) && mapInfo.contains("product") && !mapInfo["product"].startsWith("pci")) {
+        qCDebug(appLog) << "Setting model from Lshw product.";
         m_Model = mapInfo["product"];
     }
     setAttribute(mapInfo, "product", m_Name, m_Name.isEmpty() || (m_Name.startsWith("pci") && mapInfo.contains("product") && !mapInfo["product"].startsWith("pci")));
@@ -97,6 +101,7 @@ void DeviceGpu::setLshwInfo(const QMap<QString, QString> &mapInfo)
     setAttribute(mapInfo, "ioport", m_IOPort);
     setAttribute(mapInfo, "memory", m_MemAddress);
     // setAttribute(mapInfo, "physical id", m_PhysID);
+    qCDebug(appLog) << "Lshw attributes set.";
 
     if (driverIsKernelIn(m_Driver) || m_Driver.isEmpty()) {
         qCDebug(appLog) << "Driver is kernel module or empty";
@@ -105,10 +110,12 @@ void DeviceGpu::setLshwInfo(const QMap<QString, QString> &mapInfo)
 
     // 获取其他属性
     getOtherMapInfo(mapInfo);
+    qCDebug(appLog) << "DeviceGpu::setLshwInfo finished.";
 }
 
 TomlFixMethod DeviceGpu::setInfoFromTomlOneByOne(const QMap<QString, QString> &mapInfo)
 {
+    qCDebug(appLog) << "DeviceGpu::setInfoFromTomlOneByOne started.";
     TomlFixMethod ret = TOML_None;
     setTomlAttribute(mapInfo, "Model", m_Model);
     setTomlAttribute(mapInfo, "Graphics Memory", m_GraphicsMemory);
@@ -131,8 +138,10 @@ TomlFixMethod DeviceGpu::setInfoFromTomlOneByOne(const QMap<QString, QString> &m
     setTomlAttribute(mapInfo, "IRQ", m_IRQ);
     setTomlAttribute(mapInfo, "Width", m_Width);
     setAttribute(mapInfo, "Version", m_Version);
+    qCDebug(appLog) << "Toml attributes set.";
 //3. 获取设备的其它信息
     getOtherMapInfo(mapInfo);
+    qCDebug(appLog) << "DeviceGpu::setInfoFromTomlOneByOne finished, return: " << ret;
     return ret;
 }
 
@@ -145,10 +154,12 @@ bool DeviceGpu::setHwinfoInfo(const QMap<QString, QString> &mapInfo)
     setAttribute(mapInfo, "Device", m_Name, true);
     // 如果subdevice有值则使用subdevice
     if (m_Name.isEmpty() || (mapInfo.contains("SubDevice") && mapInfo["Device"].startsWith("pci") && !mapInfo["SubDevice"].startsWith("pci"))) {
+        qCDebug(appLog) << "Setting name from SubDevice.";
         setAttribute(mapInfo, "SubDevice", m_Name, true);
     }
     setAttribute(mapInfo, "Model", m_Model);
     if (m_Model.isEmpty() && !m_Name.isEmpty() && !m_Name.startsWith("pci")) {
+        qCDebug(appLog) << "Model is empty, setting model to name.";
         m_Model = m_Name;
     }
     setAttribute(mapInfo, "Revision", m_Version, false);
@@ -159,6 +170,7 @@ bool DeviceGpu::setHwinfoInfo(const QMap<QString, QString> &mapInfo)
     setAttribute(mapInfo, "Module Alias", m_Modalias);
     setAttribute(mapInfo, "VID_PID", m_VID_PID);
     m_PhysID = m_VID_PID;
+    qCDebug(appLog) << "Hwinfo attributes set.";
 
     if (driverIsKernelIn(m_Driver) || m_Driver.isEmpty()) {
         qCDebug(appLog) << "Driver is kernel module or empty";
@@ -168,30 +180,38 @@ bool DeviceGpu::setHwinfoInfo(const QMap<QString, QString> &mapInfo)
     m_SysPath = mapInfo["SysFS ID"];
     QRegularExpression reUniqueId("[a-zA-Z0-9_+-]{4}\\.(.*)");
     if (reUniqueId.match(mapInfo["Unique ID"]).hasMatch()) {
+        qCDebug(appLog) << "Unique ID matched regex, setting m_UniqueID.";
         m_UniqueID = reUniqueId.match(mapInfo["Unique ID"]).captured(1);
     }
     // read gpu-info file
     if (!m_SysPath.isEmpty()) {
+        qCDebug(appLog) << "SysPath is not empty, attempting to read gpu-info file.";
         QString pathStr = "/sys" + m_SysPath + "/gpu-info";
         QFile file(pathStr);
         if (file.open(QIODevice::ReadOnly)) {
+            qCDebug(appLog) << "gpu-info file opened successfully.";
             QString allStr(file.readAll());
             QStringList items = allStr.split("\n\n");
             file.close();
             foreach (const QString &item, items) {
-                if (item.isEmpty())
+                if (item.isEmpty()) {
+                    // qCDebug(appLog) << "Skipping empty item in gpu-info.";
                     continue;
+                }
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 QStringList items = allStr.split(":", QString::SkipEmptyParts);
 #else
                 QStringList items = allStr.split(":", Qt::SkipEmptyParts);
 #endif
-                if (items.size() != 2)
+                if (items.size() != 2) {
+                    // qCDebug(appLog) << "Skipping item with incorrect size in gpu-info: " << item;
                     continue;
+                }
                 if (items.first().trimmed() == "VRAM total size") {
                     bool ok;
                     quint64 vramSize = items.last().trimmed().toULong(&ok, 16);
                     if (ok && vramSize >= 1048576) {
+                        // qCDebug(appLog) << "VRAM total size found and valid, converting.";
                         vramSize /= 1048576;
                         auto curSize = vramSize / 1024.0;
                         if (curSize > 1) {
@@ -199,38 +219,51 @@ bool DeviceGpu::setHwinfoInfo(const QMap<QString, QString> &mapInfo)
                         } else {
                             m_GraphicsMemory = QString::number(vramSize) + "MB";
                         }
+                        // qCDebug(appLog) << "Graphics Memory set to: " << m_GraphicsMemory;
                     }
                 }
             }
+        } else {
+            qCDebug(appLog) << "Failed to open gpu-info file: " << pathStr;
         }
     }
     QString jjwFile = "/proc/gpuinfo_0";
     if (m_VID_PID.contains("0731") && QFile::exists(jjwFile)) {
+        qCDebug(appLog) << "VID_PID contains '0731' and jjwFile exists, attempting to read jjwFile.";
         QFile file(jjwFile);
         if (file.open(QIODevice::ReadOnly)) {
+            qCDebug(appLog) << "jjwFile opened successfully.";
             QString allStr(file.readAll());
             QStringList infos = allStr.split("\n");
             file.close();
             foreach (const QString &item, infos) {
-                if (item.isEmpty())
+                if (item.isEmpty()) {
+                    // qCDebug(appLog) << "Skipping empty item in jjwFile.";
                     continue;
+                }
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 QStringList items = item.split(":", QString::SkipEmptyParts);
 #else
                 QStringList items = item.split(":", Qt::SkipEmptyParts);
 #endif
-                if (items.size() != 2)
+                if (items.size() != 2) {
+                    // qCDebug(appLog) << "Skipping item with incorrect size in jjwFile: " << item;
                     continue;
+                }
                 if (items.first().trimmed() == "Memory Size") {
                     m_GraphicsMemory = items.last().trimmed();
+                    // qCDebug(appLog) << "Graphics Memory set from jjwFile: " << m_GraphicsMemory;
                     break;
                 }
             }
+        } else {
+            qCDebug(appLog) << "Failed to open jjwFile: " << jjwFile;
         }
     }
 
     // // 获取 匹配到lshw的Key
     setHwinfoLshwKey(mapInfo);
+    qCDebug(appLog) << "DeviceGpu::setHwinfoInfo finished.";
 
     // getOtherMapInfo(mapInfo);
     return true;
@@ -238,26 +271,38 @@ bool DeviceGpu::setHwinfoInfo(const QMap<QString, QString> &mapInfo)
 
 void DeviceGpu::setXrandrInfo(const QMap<QString, QString> &mapInfo)
 {
+    qCDebug(appLog) << "DeviceGpu::setXrandrInfo started.";
     // 设置分辨率属性
     m_MinimumResolution = mapInfo["minResolution"];
     m_CurrentResolution = mapInfo["curResolution"];
     m_MaximumResolution = mapInfo["maxResolution"];
+    qCDebug(appLog) << "Resolutions set: Min=" << m_MinimumResolution << ", Cur=" << m_CurrentResolution << ", Max=" << m_MaximumResolution;
 
     // 设置显卡支持的接口
-    if (mapInfo.find("HDMI") != mapInfo.end())
+    if (mapInfo.find("HDMI") != mapInfo.end()) {
+        qCDebug(appLog) << "HDMI found, setting m_HDMI.";
         m_HDMI = mapInfo["HDMI"];
+    }
 
-    if (mapInfo.find("VGA") != mapInfo.end())
+    if (mapInfo.find("VGA") != mapInfo.end()) {
+        qCDebug(appLog) << "VGA found, setting m_VGA.";
         m_VGA = mapInfo["VGA"];
+    }
 
-    if (mapInfo.find("DP") != mapInfo.end())
+    if (mapInfo.find("DP") != mapInfo.end()) {
+        qCDebug(appLog) << "DP found, setting m_DisplayPort.";
         m_DisplayPort = mapInfo["DP"];
+    }
 
-    if (mapInfo.find("eDP") != mapInfo.end())
+    if (mapInfo.find("eDP") != mapInfo.end()) {
+        qCDebug(appLog) << "eDP found, setting m_eDP.";
         m_eDP = mapInfo["eDP"];
+    }
 
-    if (mapInfo.find("DVI") != mapInfo.end())
+    if (mapInfo.find("DVI") != mapInfo.end()) {
+        qCDebug(appLog) << "DVI found, setting m_DVI.";
         m_DVI = mapInfo["DVI"];
+    }
 
     if (mapInfo.find("DigitalOutput") != mapInfo.end())
         m_Digital = mapInfo["DigitalOutput"];   // bug-105482添加新接口类型
@@ -311,26 +356,31 @@ void DeviceGpu::setGpuInfo(const QMap<QString, QString> &mapInfo)
 
 const QString &DeviceGpu::name() const
 {
+    // qCDebug(appLog) << "DeviceGpu::name called, returning: " << m_Name;
     return m_Name;
 }
 
 const QString &DeviceGpu::vendor() const
 {
+    // qCDebug(appLog) << "DeviceGpu::vendor called, returning: " << m_Vendor;
     return m_Vendor;
 }
 
 const QString &DeviceGpu::driver() const
 {
+    // qCDebug(appLog) << "DeviceGpu::driver called, returning: " << m_Driver;
     return m_Driver;
 }
 
 QString DeviceGpu::subTitle()
 {
+    // qCDebug(appLog) << "DeviceGpu::subTitle called, returning: " << m_Model;
     return m_Model;
 }
 
 const QString DeviceGpu::getOverviewInfo()
 {
+    // qCDebug(appLog) << "Getting GPU overview info";
     // 获取概况信息
     return m_Name.isEmpty() ? m_Model : m_Name;
 }
@@ -372,12 +422,15 @@ void DeviceGpu::loadOtherDeviceInfo()
 
 void DeviceGpu::loadTableData()
 {
+    qCDebug(appLog) << "Loading table data";
     // 加载表格内容
     QString tName = m_Name;
     if (!available()) {
+        qCDebug(appLog) << "Device not available, updating tName.";
         tName = "(" + tr("Unavailable") + ") " + m_Name;
     }
     m_TableData.append(tName);
     m_TableData.append(m_Vendor);
     m_TableData.append(m_Model);
+    qCDebug(appLog) << "Table data loaded.";
 }
