@@ -29,6 +29,7 @@ DeviceInput::DeviceInput()
     , m_WakeupID("")
     , m_BluetoothIsConnected(true)
 {
+    qCDebug(appLog) << "DeviceInput constructor called.";
     initFilterKey();
     m_CanEnable = true;
     m_CanUninstall = true;
@@ -44,8 +45,10 @@ bool DeviceInput::setInfoFromlshw(const QMap<QString, QString> &mapInfo)
     }
 
     // 设置基础设备信息
-    if (m_Vendor.isEmpty() || m_Vendor.contains("0x"))
+    if (m_Vendor.isEmpty() || m_Vendor.contains("0x")) {
+        qCDebug(appLog) << "Vendor is empty or contains '0x', setting vendor from mapInfo.";
         setAttribute(mapInfo, "vendor", m_Vendor);
+    }
     setAttribute(mapInfo, "", m_Model);
     setAttribute(mapInfo, "version", m_Version);
     setAttribute(mapInfo, "", m_Interface);
@@ -56,16 +59,19 @@ bool DeviceInput::setInfoFromlshw(const QMap<QString, QString> &mapInfo)
     setAttribute(mapInfo, "maxpower", m_MaximumPower);
     setAttribute(mapInfo, "speed", m_Speed);
     if (driverIsKernelIn(m_Driver)) {
+        qCDebug(appLog) << "Driver is kernel-in, setting m_CanUninstall to false.";
         m_CanUninstall = false;
     }
     // 当驱动为空，但是又是ps/2鼠键时，驱动不可更新卸载
     if (m_Driver.isEmpty() && "PS/2" == m_Interface) {
+        qCDebug(appLog) << "Driver is empty and interface is PS/2, setting m_CanUninstall to false.";
         m_CanUninstall = false;
     }
 
     // 获取其他设备信息
     getOtherMapInfo(mapInfo);
 
+    qCDebug(appLog) << "Exiting setInfoFromlshw. Returning true.";
     return true;
 }
 
@@ -85,6 +91,7 @@ TomlFixMethod DeviceInput::setInfoFromTomlOneByOne(const QMap<QString, QString>
 
 //3. 获取设备的其它信息
     getOtherMapInfo(mapInfo);
+    qCDebug(appLog) << "Exiting setInfoFromTomlOneByOne.";
     return ret;
 }
 
@@ -94,10 +101,12 @@ void DeviceInput::setInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
 
     //取触摸板的状态
     if (mapInfo.find("Model") != mapInfo.end() && mapInfo["Model"].contains("Touchpad", Qt::CaseInsensitive)) {
+        qCDebug(appLog) << "Model contains Touchpad, getting enable status from DBusTouchPad.";
         m_Enable = DBusTouchPad::instance()->getEnable();
     }
 
     if (mapInfo.find("Enable") != mapInfo.end()) {
+        qCDebug(appLog) << "Found 'Enable' in mapInfo, setting m_Enable to false.";
         m_Enable = false;
     }
     // 设置设备基本属性
@@ -114,18 +123,24 @@ void DeviceInput::setInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
     setAttribute(mapInfo, "VID_PID", m_VID_PID);
     m_PhysID = m_VID_PID;
     // 防止Serial ID为空
-    if (m_SerialID.isEmpty())
+    if (m_SerialID.isEmpty()) {
+        qCDebug(appLog) << "Serial ID is empty, setting from Unique ID.";
         m_SerialID = m_UniqueID;
+    }
 
 
     // 获取键盘的接口类型
-    if (mapInfo.find("Hotplug") != mapInfo.end())
+    if (mapInfo.find("Hotplug") != mapInfo.end()) {
+        qCDebug(appLog) << "Found 'Hotplug' in mapInfo, setting interface.";
         setAttribute(mapInfo, "Hotplug", m_Interface);
-    else
+    } else {
+        qCDebug(appLog) << "'Hotplug' not found, setting interface to PS/2.";
         m_Interface = "PS/2";
+    }
 
     // 上面的方法不适合蓝牙键盘的获取方法
     if (isBluetoothDevice(mapInfo["Device Files"])) {
+        qCDebug(appLog) << "Device is Bluetooth, setting interface to Bluetooth.";
         m_Interface = "Bluetooth";
     }
 
@@ -134,17 +149,21 @@ void DeviceInput::setInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
     setAttribute(mapInfo, "Driver", m_Driver);
     setAttribute(mapInfo, "Speed", m_Speed);
     if (driverIsKernelIn(m_Driver)) {
+        qCDebug(appLog) << "Driver is kernel-in, setting m_CanUninstall to false.";
         m_CanUninstall = false;
     }
     // 当驱动为空，但是又是ps/2鼠键时，驱动不可更新卸载
     if (m_Driver.isEmpty() && "PS/2" == m_Interface) {
+        qCDebug(appLog) << "Driver is empty and interface is PS/2, setting m_CanUninstall to false.";
         m_CanUninstall = false;
     }
 
     // ps2键盘的接口 将Device Files作为syspath解析
     if ("PS/2" == m_Interface) {
+        qCDebug(appLog) << "Interface is PS/2, getting PS2 Syspath.";
         getPS2Syspath(mapInfo["Device Files"]);
         if (m_Model.contains("Mouse", Qt::CaseInsensitive)) {
+            qCDebug(appLog) << "Model contains Mouse, setting m_CanEnable to false.";
             m_CanEnable = false;
         }
     }
@@ -152,12 +171,15 @@ void DeviceInput::setInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
     // 获取映射到 lshw设备信息的 关键字
     //1-2:1.0
     setHwinfoLshwKey(mapInfo);
+    qCDebug(appLog) << "Hwinfo Lshw Key set.";
 
     // 由bluetoothctl paired-devices设置设备接口
     setInfoFromBluetoothctl();
+    qCDebug(appLog) << "Info set from Bluetoothctl.";
 
     // 获取其他设备信息
     getOtherMapInfo(mapInfo);
+    qCDebug(appLog) << "Exiting setInfoFromHwinfo.";
 }
 
 void DeviceInput::setKLUInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
@@ -169,14 +191,19 @@ void DeviceInput::setKLUInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
     setAttribute(mapInfo, "Vendor", m_Vendor);
     setAttribute(mapInfo, "Model", m_Model);
     setAttribute(mapInfo, "Revision", m_Version);
-    if (mapInfo.find("Hotplug") != mapInfo.end())
+    if (mapInfo.find("Hotplug") != mapInfo.end()) {
+        qCDebug(appLog) << "Found 'Hotplug' in mapInfo, setting interface.";
         setAttribute(mapInfo, "Hotplug", m_Interface);
-    else
+    } else {
+        qCDebug(appLog) << "'Hotplug' not found, setting interface to PS/2.";
         m_Interface = "PS/2";
+    }
 
     // 上面的方法不适合蓝牙键盘的获取方法
-    if (mapInfo.find("Model")->contains("Bluetooth", Qt::CaseInsensitive) || mapInfo.find("Device")->contains("Bluetooth", Qt::CaseInsensitive))
+    if (mapInfo.find("Model")->contains("Bluetooth", Qt::CaseInsensitive) || mapInfo.find("Device")->contains("Bluetooth", Qt::CaseInsensitive)) {
+        qCDebug(appLog) << "Model or Device contains Bluetooth, setting interface to Bluetooth.";
         m_Interface = "Bluetooth";
+    }
 
     setAttribute(mapInfo, "SysFS BusID", m_BusInfo);
     setAttribute(mapInfo, "Hardware Class", m_Description);
@@ -187,66 +214,87 @@ void DeviceInput::setKLUInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
     //1-2:1.0
     QStringList words = mapInfo["SysFS BusID"].split(":");
     if (words.size() == 2) {
+        qCDebug(appLog) << "SysFS BusID split into 2 words.";
         QStringList chs = words[0].split("-");
-        if (chs.size() == 2)
+        if (chs.size() == 2) {
+            qCDebug(appLog) << "First word split into 2 parts, setting m_KeyToLshw.";
             m_KeyToLshw = QString("usb@%1:%2").arg(chs[0]).arg(chs[1]);
+        }
     }
 
     // 由bluetoothctl paired-devices设置设备接口
     setInfoFromBluetoothctl();
+    qCDebug(appLog) << "Info set from Bluetoothctl.";
 
     // 获取其他设备信息
     getOtherMapInfo(mapInfo);
+    qCDebug(appLog) << "Exiting setKLUInfoFromHwinfo.";
 }
 
 void DeviceInput::setInfoFromBluetoothctl()
 {
+    qCDebug(appLog) << "Entering setInfoFromBluetoothctl.";
     // 判断该设备信息是否存在于Bluetoothctl中
     if (isValueValid(m_keysToPairedDevice)) {
+        qCDebug(appLog) << "keysToPairedDevice is valid.";
         bool isExist = DeviceManager::instance()->isDeviceExistInPairedDevice(m_keysToPairedDevice.toUpper());
 
-        if (isExist)
+        if (isExist) {
+            qCDebug(appLog) << "Device exists in paired device, setting interface to Bluetooth.";
             m_Interface = "Bluetooth";
+        }
     }
+    qCDebug(appLog) << "Exiting setInfoFromBluetoothctl.";
 }
 
 bool DeviceInput::getPS2Syspath(const QString &dfs)
 {
+    qCDebug(appLog) << "Entering getPS2Syspath with device files: " << dfs;
     // 获取 dfs 中的 event
     QString eventdfs = eventStrFromDeviceFiles(dfs);
-    if (eventdfs.isEmpty())
+    if (eventdfs.isEmpty()) {
+        qCDebug(appLog) << "Event string from device files is empty. Returning false.";
         return false;
+    }
 
     QFile file("/proc/bus/input/devices");
-    if (!file.open(QIODevice::ReadOnly))
+    if (!file.open(QIODevice::ReadOnly)) {
+        qCDebug(appLog) << "Failed to open /proc/bus/input/devices. Returning false.";
         return false;
+    }
 
     QString info = file.readAll();
+    qCDebug(appLog) << "Successfully read /proc/bus/input/devices.";
     QStringList lstDevices = info.split("\n\n");
     foreach (const QString &item, lstDevices) {
+        // qCDebug(appLog) << "Processing device item: " << item.left(50) << "...";
         QStringList lines = item.split("\n");
         QString sysfs = "";
         QString event = "";
         foreach (const QString &line, lines) {
             if (line.startsWith("S:")) {
                 sysfs = line;
+                // qCDebug(appLog) << "Found sysfs line: " << sysfs;
                 continue;
             }
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             QRegExp reg("H: Handlers=.*(event[0-9]{1,2}).*");
             if (reg.exactMatch(line)) {
                 event = reg.cap(1);
+                // qCDebug(appLog) << "Matched event using QRegExp: " << event;
             }
 #else
             QRegularExpression reg("H: Handlers=.*(event[0-9]{1,2}).*");
             QRegularExpressionMatch match = reg.match(line);
             if (match.hasMatch()) {
                 event = match.captured(1);
+                // qCDebug(appLog) << "Matched event using QRegularExpression: " << event;
             }
 #endif
         }
 
         if (!event.isEmpty() && !sysfs.isEmpty()) {
+            // qCDebug(appLog) << "Event and sysfs are not empty. Checking for match.";
             if (event == eventdfs) {
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
                 QRegExp regfs;
@@ -272,11 +320,13 @@ bool DeviceInput::getPS2Syspath(const QString &dfs)
         }
     }
 
+    qCDebug(appLog) << "getPS2Syspath end";
     return true;
 }
 
 bool DeviceInput::isBluetoothDevice(const QString &dfs)
 {
+    qCDebug(appLog) << "isBluetoothDevice";
     // 获取 dfs 中的 event
     QString eventdfs = eventStrFromDeviceFiles(dfs);
     if (eventdfs.isEmpty()) {
@@ -345,6 +395,7 @@ bool DeviceInput::isBluetoothDevice(const QString &dfs)
 
 QString DeviceInput::eventStrFromDeviceFiles(const QString &dfs)
 {
+    qCDebug(appLog) << "eventStrFromDeviceFiles";
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     QRegularExpression regdfs(".*(event[0-9]{1,2}).*");
     QRegularExpressionMatch match = regdfs.match(dfs);
@@ -355,50 +406,64 @@ QString DeviceInput::eventStrFromDeviceFiles(const QString &dfs)
     if (regdfs.exactMatch(dfs))
         return regdfs.cap(1);
 #endif
+    qCDebug(appLog) << "eventStrFromDeviceFiles end";
     return "";
 }
 
 const QString &DeviceInput::name() const
 {
+    // qCDebug(appLog) << "Entering name() const.";
+    // qCDebug(appLog) << "Exiting name() const. Returning: " << m_Name;
     return m_Name;
 }
 
 const QString &DeviceInput::vendor() const
 {
+    // qCDebug(appLog) << "vendor";
     return m_Vendor;
 }
 
 const QString &DeviceInput::driver() const
 {
+    // qCDebug(appLog) << "driver";
     return m_Driver;
 }
 
 bool DeviceInput::available()
 {
+    // qCDebug(appLog) << "available";
     if (driver().isEmpty()) {
+        // qCDebug(appLog) << "driver is empty";
         m_Available = false;
     }
     if ("PS/2" == m_Interface || "Bluetooth" == m_Interface) {
+        // qCDebug(appLog) << "interface is PS/2 or Bluetooth";
         m_Available = true;
     }
+    // qCDebug(appLog) << "available end";
     return m_forcedDisplay ? m_forcedDisplay : m_Available;
 }
 
 QString DeviceInput::subTitle()
 {
+    // qCDebug(appLog) << "subTitle";
     // 获取子标题
-    if (!m_Name.isEmpty())
+    if (!m_Name.isEmpty()) {
+        // qCDebug(appLog) << "name is not empty";
         return m_Name;
+    }
+    // qCDebug(appLog) << "name is empty";
     return m_Model;
 }
 
 const QString DeviceInput::getOverviewInfo()
 {
+    // qCDebug(appLog) << "getOverviewInfo";
     // 获取概况信息
     QString ov = QString("%1 (%2)") \
                  .arg(m_Name) \
                  .arg(m_Model);
-
+    // qCDebug(appLog) << "getOverviewInfo end, ov:" << ov;
     return ov;
 }
 
@@ -412,16 +477,20 @@ const QString DeviceInput::getOverviewInfo()
 
 EnableDeviceStatus DeviceInput::setEnable(bool e)
 {
+    qCDebug(appLog) << "setEnable";
     if (m_Name.contains("Touchpad", Qt::CaseInsensitive)) {
+        qCDebug(appLog) << "setEnable touchpad";
         DBusTouchPad::instance()->setEnable(e);
         m_Enable = e;
         return EDS_Success;
     } else {
         if (m_SerialID.isEmpty()) {
+            qCDebug(appLog) << "setEnable no serial";
             return EDS_NoSerial;
         }
 
         if (m_UniqueID.isEmpty() || m_SysPath.isEmpty()) {
+            qCDebug(appLog) << "setEnable no unique id or sys path";
             return EDS_Faild;
         }
         if(e){
@@ -438,32 +507,42 @@ EnableDeviceStatus DeviceInput::setEnable(bool e)
             m_Enable = e;
         }
         // 设置设备状态
+        qCDebug(appLog) << "setEnable res:" << res;
         return res ? EDS_Success : EDS_Faild;
     }
 }
 
 bool DeviceInput::enable()
 {
+    // qCDebug(appLog) << "enable";
     // 键盘不可禁用
     if (m_HardwareClass == "keyboard") {
+        // qCDebug(appLog) << "enable keyboard";
         m_Enable = true;
     }
+    // qCDebug(appLog) << "enable end";
     return m_Enable;
 }
 
 bool DeviceInput::canWakeupMachine()
 {
-    if (m_WakeupID.isEmpty() || (m_HardwareClass == "keyboard" && "PS/2" == m_Interface))
-        return false;
-    QFile file(wakeupPath());
-    if (!file.open(QIODevice::ReadOnly)) {
+    qCDebug(appLog) << "canWakeupMachine";
+    if (m_WakeupID.isEmpty() || (m_HardwareClass == "keyboard" && "PS/2" == m_Interface)) {
+        qCDebug(appLog) << "canWakeupMachine return false";
         return false;
     }
+    QFile file(wakeupPath());
+    if (!file.open(QIODevice::ReadOnly)) {
+        qCDebug(appLog) << "canWakeupMachine open file failed";
+        return false;
+    }
+    qCDebug(appLog) << "canWakeupMachine end";
     return true;
 }
 
 bool DeviceInput::isWakeupMachine()
 {
+    qCDebug(appLog) << "isWakeupMachine";
     QFile file(wakeupPath());
     if (!file.open(QIODevice::ReadOnly)) {
         qCDebug(appLog) << "open wakeup file failed";
@@ -494,31 +573,39 @@ bool DeviceInput::isWakeupMachine()
 
 QString DeviceInput::wakeupPath()
 {
+    qCDebug(appLog) << "wakeupPath";
     int index = m_SysPath.lastIndexOf('/');
     if (index < 1) {
+        qCDebug(appLog) << "wakeupPath index < 1";
         return "";
     }
 
     if (m_Name.contains("PS/2")) {
+        qCDebug(appLog) << "wakeupPath ps2";
         return "/proc/acpi/wakeup";
     } else {
+        qCDebug(appLog) << "wakeupPath usb";
         return QString("/sys") + m_SysPath.left(index) + QString("/power/wakeup");
     }
+    qCDebug(appLog) << "wakeupPath end";
 }
 
 const QString &DeviceInput::wakeupID()
 {
+    // qCDebug(appLog) << "wakeupID";
     return m_WakeupID;
 }
 
 bool DeviceInput::bluetoothIsConnected()
 {
+    // qCDebug(appLog) << "bluetoothIsConnected";
     return m_BluetoothIsConnected;
 }
 
 void DeviceInput::initFilterKey()
 {
     // 添加可显示的设备信息
+    qCDebug(appLog) << "initFilterKey";
     addFilterKey(QObject::tr("Uniq"));
     addFilterKey(QObject::tr("PROP"));
     addFilterKey(QObject::tr("EV"));
@@ -528,21 +615,24 @@ void DeviceInput::initFilterKey()
     addFilterKey(QObject::tr("Hardware Class"));
 
     // addFilterKey(QObject::tr("physical id"));
-
+    qCDebug(appLog) << "initFilterKey end";
 }
 
 void DeviceInput::loadBaseDeviceInfo()
 {
+    qCDebug(appLog) << "loadBaseDeviceInfo";
     // 添加基本信息
     addBaseDeviceInfo(tr("Name"), m_Name);
     addBaseDeviceInfo(tr("Vendor"), m_Vendor);
     addBaseDeviceInfo(tr("Model"), m_Model);
     addBaseDeviceInfo(tr("Interface"), m_Interface);
     addBaseDeviceInfo(tr("Bus Info"), m_BusInfo);
+    qCDebug(appLog) << "loadBaseDeviceInfo end";
 }
 
 void DeviceInput::loadOtherDeviceInfo()
 {
+    qCDebug(appLog) << "loadOtherDeviceInfo";
     // 添加其他信息,成员变量
     addOtherDeviceInfo(tr("Module Alias"), m_Modalias);
     addOtherDeviceInfo(tr("Physical ID"), m_PhysID);
@@ -554,23 +644,28 @@ void DeviceInput::loadOtherDeviceInfo()
 
     // 将QMap<QString, QString>内容转存为QList<QPair<QString, QString>>
     mapInfoToList();
+    qCDebug(appLog) << "loadOtherDeviceInfo end";
 }
 
 void DeviceInput::loadTableData()
 {
+    qCDebug(appLog) << "loadTableData";
     // 加载表格数据
     QString tName = m_Name;
 
     if (!available()) {
+        qCDebug(appLog) << "loadTableData unavailable";
         tName = "(" + tr("Unavailable") + ") " + m_Name;
     }
 
     if (!enable()) {
+        qCDebug(appLog) << "loadTableData disable";
         tName = "(" + tr("Disable") + ") " + m_Name;
     }
 
     m_TableData.append(tName);
     m_TableData.append(m_Vendor);
     m_TableData.append(m_Model);
+    qCDebug(appLog) << "loadTableData end";
 }
 
