@@ -29,36 +29,41 @@ LoadInfoThread::LoadInfoThread()
     , m_FinishedReadFilePool(false)
     , m_Start(true)
 {
-    qDebug() << "LoadInfoThread constructor";
+    qCDebug(appLog) << "LoadInfoThread constructor";
     connect(&mp_ReadFilePool, &GetInfoPool::finishedAll, this, &LoadInfoThread::slotFinishedReadFilePool);
 }
 
 LoadInfoThread::~LoadInfoThread()
 {
-    qDebug() << "LoadInfoThread destructor start";
+    qCDebug(appLog) << "LoadInfoThread destructor start";
     long long begin = QDateTime::currentMSecsSinceEpoch();
     while (m_Running)
     {
+        // qCDebug(appLog) << "LoadInfoThread destructor waiting for thread to finish";
         long long end = QDateTime::currentMSecsSinceEpoch();
-        if (end - begin > 1000)
+        if (end - begin > 1000) {
+            qCWarning(appLog) << "LoadInfoThread destructor timeout, force exit";
             _exit(0);
+        }
         usleep(100);
     }
     mp_ReadFilePool.deleteLater();
     mp_GenerateDevicePool.deleteLater();
-    qDebug() << "LoadInfoThread destructor end";
+    qCDebug(appLog) << "LoadInfoThread destructor end";
 }
 
 
 void LoadInfoThread::run()
 {
-    qDebug() << "LoadInfoThread::run start";
+    qCDebug(appLog) << "LoadInfoThread::run start";
     // 判断后台是否正处理update状态
     QString info;
     DBusInterface::getInstance()->getInfo("is_server_running", info);
+    qCDebug(appLog) << "LoadInfoThread::run is_server_running:" << info;
     // 请求后台更新信息
     m_Running = true;
     if (!info.toInt()) {
+        qCDebug(appLog) << "LoadInfoThread::run server is not running, start to get info";
         m_Start = false;
         mp_ReadFilePool.getAllInfo();
         mp_ReadFilePool.waitForDone(-1);
@@ -66,7 +71,9 @@ void LoadInfoThread::run()
         bool readDataFlag = false;
         int readNum = 0;
         while (!readDataFlag) {
+            // qCDebug(appLog) << "LoadInfoThread::run waiting for read data, readNum:" << readNum;
             if (m_FinishedReadFilePool) {
+                // qCDebug(appLog) << "LoadInfoThread::run finished read file pool, get all info again";
                 mp_ReadFilePool.getAllInfo();
                 mp_ReadFilePool.waitForDone(-1);
             }
@@ -74,24 +81,35 @@ void LoadInfoThread::run()
             long long begin = QDateTime::currentMSecsSinceEpoch();
             while (true) {
                 readDataFlag = !DeviceManager::instance()->cmdInfo("dmidecode4").isEmpty();
-                if (readDataFlag && m_FinishedReadFilePool)
+                if (readDataFlag && m_FinishedReadFilePool) {
+                    // qCDebug(appLog) << "LoadInfoThread::run read data finished";
                     break;
+                }
                 long long end = QDateTime::currentMSecsSinceEpoch();
-                if (end - begin > 4000)
+                if (end - begin > 4000) {
+                    // qCWarning(appLog) << "LoadInfoThread::run read data timeout";
                     break;
+                }
                 usleep(100);
             }
             if ((++readNum) > 3) {
+                // qCWarning(appLog) << "LoadInfoThread::run read data retry timeout";
                 if (m_FinishedReadFilePool && !readDataFlag) {
+                    // qCDebug(appLog) << "LoadInfoThread::run finished read file pool, but read data failed, get all info again";
                     mp_ReadFilePool.getAllInfo();
                     mp_ReadFilePool.waitForDone(-1);
                     begin = QDateTime::currentMSecsSinceEpoch();
                     while (true) {
-                        if (m_FinishedReadFilePool)
+                        // qCDebug(appLog) << "LoadInfoThread::run waiting for read file pool finished";
+                        if (m_FinishedReadFilePool) {
+                            // qCDebug(appLog) << "LoadInfoThread::run read file pool finished";
                             break;
+                        }
                         long long end = QDateTime::currentMSecsSinceEpoch();
-                        if (end - begin > 4000)
+                        if (end - begin > 4000) {
+                            // qCWarning(appLog) << "LoadInfoThread::run wait for read file pool finished timeout";
                             break;
+                        }
                         usleep(100);
                     }
                 }
@@ -102,19 +120,22 @@ void LoadInfoThread::run()
         m_FinishedReadFilePool = false;
         mp_GenerateDevicePool.generateDevice();
         mp_GenerateDevicePool.waitForDone(-1);
+    } else {
+        qCDebug(appLog) << "LoadInfoThread::run server is running, do nothing";
     }
 
     emit finished("finish");
     m_Running = false;
-    qDebug() << "LoadInfoThread::run end";
+    qCDebug(appLog) << "LoadInfoThread::run end";
 }
 
 void LoadInfoThread::slotFinishedReadFilePool(const QString &)
 {
-    qDebug() << "LoadInfoThread::slotFinishedReadFilePool";
+    qCDebug(appLog) << "LoadInfoThread::slotFinishedReadFilePool";
     m_FinishedReadFilePool = true;
     // 首次加载刷新
     if (firstLoadFlag) {
+        qCDebug(appLog) << "LoadInfoThread::slotFinishedReadFilePool first load, emit finishedReadFilePool";
         firstLoadFlag = false;
         emit finishedReadFilePool();
     }
@@ -122,7 +143,7 @@ void LoadInfoThread::slotFinishedReadFilePool(const QString &)
 
 void LoadInfoThread::setFramework(const QString &arch)
 {
-    qDebug() << "LoadInfoThread::setFramework, arch:" << arch;
+    qCDebug(appLog) << "LoadInfoThread::setFramework, arch:" << arch;
     // 设置架构
     mp_ReadFilePool.setFramework(arch);
 }
