@@ -16,11 +16,12 @@ using namespace DDLog;
 GetDriverNameModel::GetDriverNameModel(QObject *parent)
     : QObject(parent)
 {
-
+    qCDebug(appLog) << "Initializing get driver name model";
 }
 
 void GetDriverNameModel::stopLoadingDrivers()
 {
+    qCDebug(appLog) << "Stopping driver loading";
     m_Stop = true;
 }
 
@@ -30,6 +31,7 @@ void GetDriverNameModel::startLoadDrivers(QStandardItemModel* model, bool includ
 
     m_Stop = false;
     if(includeSub){
+        qCDebug(appLog) << "Including sub folders";
         mp_driverPathList.clear();
         mp_driversList.clear();
 
@@ -38,18 +40,22 @@ void GetDriverNameModel::startLoadDrivers(QStandardItemModel* model, bool includ
                 mp_driversList.append(QFileInfo(filepath).fileName());
             }
         }else{
+            qCWarning(appLog) << "Failed to search driver via DBus, traversing folders instead";
             traverseFolders(path,true);
         }
     }else{
         // 获取所有的驱动文件
+        qCDebug(appLog) << "Not including sub folders";
         mp_driverPathList.clear();
         mp_driversList.clear();
         traverseFolders(path);
     }
 
     for (int i = 0; i < mp_driversList.size(); i++) {
-        if(m_Stop)
+        if(m_Stop) {
+            qCDebug(appLog) << "Driver loading stopped, return";
             return;
+        }
         QStandardItem *icomItem = new QStandardItem;
         //获取应用文件图标
         QFileInfo info(mp_driverPathList[i]);
@@ -70,11 +76,15 @@ void GetDriverNameModel::traverseFolders(const QString &path, bool recursion)
 {
     qCDebug(appLog) << "Traversing folder:" << path << "recursion:" << recursion;
 
-    if(m_Stop)
+    if(m_Stop) {
+        qCDebug(appLog) << "Stop traversing folders";
         return;
+    }
     QDir dir(path);
-    if (!dir.exists())
+    if (!dir.exists()) {
+        qCWarning(appLog) << "Directory does not exist:" << path;
         return;
+    }
 
     QStringList nameFiltes;
     nameFiltes << "*.deb" << "*.ko";
@@ -87,6 +97,7 @@ void GetDriverNameModel::traverseFolders(const QString &path, bool recursion)
 
     // 递归处理子文件夹
     if(recursion){
+        qCDebug(appLog) << "Recursively traversing sub folders";
         list = dir.entryInfoList(QDir::Dirs | QDir::NoSymLinks | QDir::NoDotAndDotDot);
         foreach(const QFileInfo& info , list){
             traverseFolders(info.absoluteFilePath(),recursion);
